#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ULP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ULP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/ulp.hpp>

#endif
